<?php

/**
 * @file
 * Views field handler for the Comment Timer's seconds field.
 */
class comment_timer_handler_field_seconds extends views_handler_field_numeric {
  function render($values) {
    if ($this->options['comment_timer_seconds']) {
      return parent::render($values);
    }
    return _comment_timer_seconds_to_hms($values->{$this->field_alias});
  }

  function access() {
    if (!user_access('access comment timer')) {
      // User is not permitted to access comment timer.
      return FALSE;
    }
    return parent::access();
  }

  function option_definition() {
    $options = parent::option_definition();
    $options['comment_timer_seconds'] = array('default' => 0);
    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $form['comment_timer_seconds'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display as number of seconds'),
      '#description' => t('Time will be displayed as seconds when enabled (instead of HH:MM:SS).'),
      '#default_value' => $this->options['comment_timer_seconds'],
      '#weight' => -1,
    );
    // Numeric-related settings should be #states-hidden if this is unticked.
    $form['separator']['#dependency']['edit-options-comment-timer-seconds'][0] = TRUE;
    $form['format_plural']['#dependency']['edit-options-comment-timer-seconds'][0] = TRUE;
  }
}
